==> pointsto-19.2.0.1-sources.jar: com/oracle/graal/pointsto/flow/SourceTypeFlow.java <==
/*
 * Copyright (c) 2013, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.graal.pointsto.flow;

import org.graalvm.compiler.nodes.ValueNode;
import com.oracle.graal.pointsto.BigBang;
import com.oracle.graal.pointsto.typestate.TypeState;

public class SourceTypeFlow extends SourceTypeFlowBase {

    /**
     * Source flow has an immutable type state.
     */
    public SourceTypeFlow(ValueNode node, TypeState state) {
        super(node, state);
    }

    public SourceTypeFlow(BigBang bb, SourceTypeFlow original, MethodFlowsGraph methodFlows) {
        super(bb, original, methodFlows);
    }

    @Override
    public TypeFlow<ValueNode> copy(BigBang bb, MethodFlowsGraph methodFlows) {
        return new SourceTypeFlow(bb, this, methodFlows);
    }

    @Override
    public String toString() {
        StringBuilder str = new StringBuilder();
        str.append("SourceFlow<").append(getState()).append(">");
        return str.toString();
    }
}

==> pointsto-21.0.0-sources.jar: com/oracle/graal/pointsto/flow/SourceTypeFlow.java <==
/*
 * Copyright (c) 2013, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.graal.pointsto.flow;

import org.graalvm.compiler.nodes.ValueNode;

import com.oracle.graal.pointsto.BigBang;
import com.oracle.graal.pointsto.typestate.TypeState;

import jdk.vm.ci.code.BytecodePosition;

public class SourceTypeFlow extends SourceTypeFlowBase {

    /**
     * Source flow has an immutable type state.
     */
    public SourceTypeFlow(ValueNode node, TypeState state) {
        super(node, state);
    }

    public SourceTypeFlow(BigBang bb, SourceTypeFlow original, MethodFlowsGraph methodFlows) {
        super(bb, original, methodFlows);
    }

    @Override
    public TypeFlow<BytecodePosition> copy(BigBang bb, MethodFlowsGraph methodFlows) {
        return new SourceTypeFlow(bb, this, methodFlows);
    }

    @Override
    public String toString() {
        StringBuilder str = new StringBuilder();
        str.append("SourceFlow<").append(getState()).append(">");
        return str.toString();
    }
}
